#include <Application.h>
#include <cmsis_os2.h>
#include <Platform.h>
#include <stdbool.h>

enum LedState
{
	LED_STATE_OFF = 0,
	LED_STATE_ON = 1,
	LED_STATE_BLINK = 2
};

static enum LedState ledState;
static bool ledValue = false;
static osSemaphoreId_t semBlink;

void Application_onPushButtonChanged( void )
{
  switch (ledState)
  {
  case LED_STATE_OFF:
    ledState = LED_STATE_BLINK;
    osSemaphoreRelease(semBlink);
    break;
  case LED_STATE_ON:
    ledState = LED_STATE_OFF;
    ledValue = false;
    break;
  case LED_STATE_BLINK:
    ledState = LED_STATE_ON;
    ledValue = true;
    break;
  }
  Platform_Led_setValue(ledValue);
}

void Application_run()
{
  semBlink = osSemaphoreNew(1, 0, NULL);
  ledState = LED_STATE_BLINK;
  ledValue = false;
  Platform_PushButton_setIsrCallback( Application_onPushButtonChanged );
  Platform_PushButton_enableInterrupt();
  while( true )
  {
    while (LED_STATE_BLINK == ledState)
    {
      ledValue = !ledValue;
      Platform_Led_setValue(ledValue);
      osDelay(500);
    }
    osSemaphoreAcquire(semBlink, osWaitForever);
  }
}
