/*
 * libredBlocks_sim_uvision_rtx.h 
 * redBlocks Library - Version 2.13.0 - Evaluation Version.
 * Copyright  redlogix Software & System Engineering GmbH, 2012-2020. All rights reserved. 
 *
 * The source code in this file may be incomplete compared to its Commercial Version's counterpart. 
 * However, it may be used in its present form for developing commercial applications if at least 
 * one component of the redBlocks Library is commercially licensed for the respective application.
 * 
 * If not being used together with at least one commercially licensed component of the redBlocks 
 * Library it may be used for evaluation purposes ONLY. 
 *
 * In any case you may not: 
 * (a) to a third party, transfer rights or usage to, sublicense, rent, lease or otherwise distribute 
 *     the source code, or any portions thereof, except with redlogix's prior written consent.
 * (b) create derivative source code of the software.
 * (c) modify, loan, decompile, reverse engineer or disassemble or otherwise distribute the software, 
 *     except with redlogix's prior written consent.
 * (d) remove any intellectual property notices within the software.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITH POTENTIAL FAULTS.
 * NO WARRANTIES, WHETHER EXPLICITLY EXPRESSED, IMPLIED OR STATUTORY, INCLUDING, BUT
 * NOT LIMITED TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. REDLOGIX SHALL NOT, UNDER ANY
 * CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR CONSEQUENTIAL
 * DAMAGES, FOR ANY REASON WHATSOEVER.
 */

#ifndef LIBREDBLOCKS_SIM_UVISION_RTX_H_
#define LIBREDBLOCKS_SIM_UVISION_RTX_H_

#include <rbCTypes.h>
#include <libredBlocks_sim.h>

#ifdef __cplusplus
extern "C"
{
#endif

/**
 * @ingroup module_target_sim_c_api
 * Initializes the simulation library with the uVision debugger connection for data exchange with the simulator.
 * It also sets up an RTX thread as simulation context that calls the function rb_sim_tick() 100 times per second.
 * I. e. when setting up the simulation environment with this function, the user must not invoke the function
 * rb_sim_tick() periodically.
 *
 * @param userStack      specifies an additional stack size for user callbacks, which will typically be set to 0.
 *                       Per default the stack size of the spawned thread that calls rb_sim_tick() periodically is 512 bytes.
 *                       This is sufficient for most scenarios, as it leaves about 200 bytes for callback functions the user
 *                       registers with driver stubs. However, if there are ISR callbacks that need more stack size, set it to
 *                       a sufficient value. The total stack size of the spawned thread will be 512 + @c userStack.
 * @param sharedMemoryAddress address of the used shared memory region that is used to communicate with the simulator.
 *                       The size of the specified memory region must be at least: 52 + recvBufferSize + sendBufferSize.
 * @param recvBufferSize the size of the receive buffer.
 *                       The minimum size of the receive buffer is 100 bytes.
 * @param sendBufferSize the size of the send buffer.
 *                       The minimum size of the send buffer is 100 bytes.
 */
void rb_sim_uvision_initRtx( u16 userStack, u32 sharedMemoryAddress, u16 recvBufferSize, u16 sendBufferSize );

#ifdef __cplusplus
}
#endif

#endif // LIBREDBLOCKS_SIM_UVISION_RTX_H_
