/*
 * rbConfig-default.h 
 * redBlocks Library - Version 2.13.0 - Evaluation Version.
 * Copyright  redlogix Software & System Engineering GmbH, 2012-2020. All rights reserved. 
 *
 * The source code in this file may be incomplete compared to its Commercial Version's counterpart. 
 * However, it may be used in its present form for developing commercial applications if at least 
 * one component of the redBlocks Library is commercially licensed for the respective application.
 * 
 * If not being used together with at least one commercially licensed component of the redBlocks 
 * Library it may be used for evaluation purposes ONLY. 
 *
 * In any case you may not: 
 * (a) to a third party, transfer rights or usage to, sublicense, rent, lease or otherwise distribute 
 *     the source code, or any portions thereof, except with redlogix's prior written consent.
 * (b) create derivative source code of the software.
 * (c) modify, loan, decompile, reverse engineer or disassemble or otherwise distribute the software, 
 *     except with redlogix's prior written consent.
 * (d) remove any intellectual property notices within the software.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITH POTENTIAL FAULTS.
 * NO WARRANTIES, WHETHER EXPLICITLY EXPRESSED, IMPLIED OR STATUTORY, INCLUDING, BUT
 * NOT LIMITED TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. REDLOGIX SHALL NOT, UNDER ANY
 * CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR CONSEQUENTIAL
 * DAMAGES, FOR ANY REASON WHATSOEVER.
 */

#ifndef RB_CONFIG_DEFAULT_H_
#define RB_CONFIG_DEFAULT_H_

/*
 * Global configuration file for the redBlocks library.
 *
 * This file is not meant to be changed. Instead, it needs to be included at the end of
 * an application-specific configuration file rbConfig.h
 *
 * Its purpose is to set all definitions to default values, that are not explicitly
 * specified in rbConfig.h
 */

#if !defined(RB_USE_STDINT_TYPES)
/*
 * If this macro is set to 1, the data types uint8_t, sint8_t, uint16_t, ...
 * from stdint.h are used in order to define u8, s8, u16, ..., i.e. they are
 * mere aliases for the corresponding stdint.h data types. Otherwise,
 * the data types char, short, long, ... are used to define u8, u16, u32, ...
 * If not otherwise specified, this configuration parameter defaults to 1. It
 * is recommended to use this default value, unless the platform does not provide
 * the required data types with stdint.h. In this case, it needs to be set to 0.
 */
#define RB_USE_STDINT_TYPES 1
#endif

#if (!defined(RB_TARGET_ENDIANNESS_LITTLE)) && (!defined(RB_TARGET_ENDIANNESS_BIG))
/*
 * Macros to define the target's endianness (relevant to determine the byte order
 * during serialization).
 * Values:
 * - <b>RB_TARGET_ENDIANNESS_LITTLE</b>  for little endian targets
 * - <b>RB_TARGET_ENDIANNESS_BIG</b>     for big endian targets
 */
#define RB_TARGET_ENDIANNESS_LITTLE
#endif

#if (!defined(RB_PACKED_STYLE_GNU)) && (!defined(RB_PACKED_STYLE_ARM))
/*
 * Macro setting the compiler directive style for packing structs and enums (see rbPacked.h for details).
 * Values:
 * - <b>RB_PACKED_STYLE_GNU</b>  for gnu compiler style
 * - <b>RB_PACKED_STYLE_ARM</b>  for arm compiler style
 */
#define RB_PACKED_STYLE_GNU
#endif

#if (!defined(RB_ERROR_HANDLER_CLASS))
/*
 * Specifies the fully qualified name of the class that is used for error handling.
 */
#define RB_ERROR_HANDLER_CLASS redBlocks::Core::ResetErrorHandler
#endif

#if (!defined(RB_ERROR_HANDLER_INC))
/*
 * Specifies the include path of the header file where the error handler class is defined.
 */
#define RB_ERROR_HANDLER_INC   <Core/Error/ResetErrorHandler.h>
#endif

#if (!defined(RB_STD_LOGGER_CLASS))
/*
 * Specifies the fully qualified name of the class that is used for logging.
 */
#define RB_STD_LOGGER_CLASS Platform::StandardLogger
#else
#define __RB_LOG_ON_DEFAULT 1
#endif

#if (!defined(RB_STD_LOGGER_INC))
/*
 * Specifies the include path of the header file where the standard logger class is defined.
 */
#define RB_STD_LOGGER_INC   <Platform.h>
#endif


#if !defined(RB_LOG_ON)
#if !defined(__RB_LOG_ON_DEFAULT)
/*
 * Set to 1 in order to switch logging on, specify 0 in order to
 * turn off all logging functionality. If no value is explicitly specified,
 * logging is per default turned on, if RB_STD_LOGGER_CLASS was defined.
 */
#define RB_LOG_ON 0
#else
#define RB_LOG_ON __RB_LOG_ON_DEFAULT
#endif
#endif


#if !defined(RB_LOG_DEBUG_ON)
/*
 * Set to 1 in order to switch debug logging on, specify 0 in order to turn it off.
 */
#define RB_LOG_DEBUG_ON 1
#endif

#if !defined(RB_LOG_INFO_ON)
/*
 * Set to 1 in order to switch info logging on, specify 0 in order to turn it off.
 */
#define RB_LOG_INFO_ON 1
#endif

#if !defined(RB_LOG_WARN_ON)
/*
 * Set to 1 in order to switch warning logging on, specify 0 in order to turn it off.
 */
#define RB_LOG_WARN_ON 1
#endif

#if !defined(RB_LOG_ERROR_ON)
/*
 * Set to 1 in order to switch error logging on, specify 0 in order to turn it off.
 */
#define RB_LOG_ERROR_ON 1
#endif

#if !defined(RB_LOG_LOCATION_ON)
/*
 * If this macro is set to 1, additional information is output with each
 * logging message that identifies where the logging message was generated
 * (file name and line number).
 * The compiler must support the auto generated macros __FILE__ and __LINE__
 * for this feature to work.
 * In order to deactivate this feature, set this define to 0.
 */
#define RB_LOG_LOCATION_ON 1
#endif

#if !defined(RB_LOG_COMPATIBILITY_ON)
/*
 * Enables backward compatibility for logging facility.
 */
#define RB_LOG_COMPATIBILITY_ON 1
#endif

#endif // RB_CONFIG_DEFAULT_H_
