/**
 * Include this header file in all compilation units before legacy library header files,
 * that define the same data types u8, u16, ... as defined in rbCTypes.h.
 *
 * It redefines any occurrance of u8, u16, ... in order to avoid multiple definition errors.
 *
 * Usage:
 * @code
   #include <rbLegacyIncludes.h>

   #include <legacy_include1.h>
   #include <legacy_include2.h>
   // ...

   #include <rbTypes.h>
   // other redBlocks includes

   @endcode
 *
 * Note that it is only necessary to include this file before legacy library headers, if they define
 * the data types u8, u16, ...
 *
 */
#ifndef RB_LEGACY_INCLUDES_H_
#define RB_LEGACY_INCLUDES_H_

#define u64 rbLegacy_u64
#define s64 rbLegacy_s64
#define u32 rbLegacy_u32
#define s32 rbLegacy_s32
#define u16 rbLegacy_u16
#define s16 rbLegacy_s16
#define u8  rbLegacy_u8
#define s8  rbLegacy_s8

#endif // RB_LEGACY_INCLUDES_H_
